@@ -27,12 +27,20 @@ from numba.external.utility import default_utility_library
 
 logger = logging.getLogger(__name__)
 
+if PY3:
+    NoneType = type(None)
+    name_types = str
+else:
+    NoneType = types.NoneType
+    name_types = (str, unicode)
+
 default_pipeline_order = [
     'ast3to2',
     'resolve_templates',
     'validate_signature',
     'update_signature',
     'create_lfunc1',
+    'NormalizeASTStage',
     'ControlFlowAnalysis',
     #'ConstFolding',
     'TypeInfer',
@@ -53,6 +61,7 @@ default_pipeline_order = [
     'SpecializeLoops',
     'FixASTLocations',
     'LateSpecializer',
+    'ExtensionTypeLowerer',
     'SpecializeFunccalls',
     'SpecializeExceptions',
     'FixASTLocations',
@@ -92,6 +101,7 @@ default_numba_late_translate_pipeline_order = \
     default_numba_lower_pipeline_order + [
     'CodeGen',
 ]
+
 # ______________________________________________________________________
 # Convenience functions
 
@@ -119,7 +129,7 @@ class FunctionErrorEnvironment(object):
     """
 
     func = WriteOnceTypedProperty(
-        (types.NoneType, types.FunctionType),
+        (NoneType, types.FunctionType),
         'Function (or similar) being translated.')
 
     ast = TypedProperty(
@@ -209,12 +219,12 @@ class FunctionEnvironment(object):
         "Error environment for this function.")
 
     lfunc = TypedProperty(
-        (types.NoneType, llvm.core.Function),
+        (NoneType, llvm.core.Function),
         "Compiled, native, Numba function",
         None)
 
     lfunc_pointer = TypedProperty(
-        (int, long),
+        (int, long) if not PY3 else int,
         "Pointer to underlying compiled function. Can be used as a callback.",
     )
 
@@ -231,7 +241,7 @@ class FunctionEnvironment(object):
         True)
 
     llvm_wrapper_func = TypedProperty(
-        (llvm.core.Function, types.NoneType),
+        (llvm.core.Function, NoneType),
         'The LLVM wrapper function for the target function.  This is a '
         'wrapper function that accept python object arguments and returns an '
         'object.')
@@ -249,7 +259,7 @@ class FunctionEnvironment(object):
         '({ "local_var_name" : numba.symtab.Variable(local_var_type) })')
 
     function_globals = TypedProperty(
-        (dict, types.NoneType),
+        (dict, NoneType),
         "Globals dict of the function",)
 
     locals = TypedProperty(
@@ -268,7 +278,7 @@ class FunctionEnvironment(object):
         'Metadata for AST nodes of the function being compiled.')
 
     flow = TypedProperty(
-        (types.NoneType, ControlFlow),
+        (NoneType, ControlFlow),
         "Control flow graph. See numba.control_flow.",
         default=None)
 
@@ -301,7 +311,7 @@ class FunctionEnvironment(object):
         dict, 'Map from ast nodes to closures.')
 
     closure_scope = TypedProperty(
-        (dict, types.NoneType),
+        (dict, NoneType),
         'Collective symtol table containing all entries from outer '
         'functions.')
 
@@ -457,7 +467,7 @@ class TranslationEnvironment(object):
     numba = TypedProperty(_AbstractNumbaEnvironment, 'Parent environment')
 
     crnt = TypedProperty(
-        (FunctionEnvironment, types.NoneType),
+        (FunctionEnvironment, NoneType),
         'The environment corresponding to the current function under '
         'translation.')
 
@@ -656,7 +666,7 @@ class NumbaEnvironment(_AbstractNumbaEnvironment):
     # ____________________________________________________________
     # Properties
 
-    name = TypedProperty((str, unicode), "Name of the environment.")
+    name = TypedProperty(name_types, "Name of the environment.")
 
     pipelines = TypedProperty(
         dict, 'Map from entry point names to PipelineStages.')
