@@ -52,4 +52,4 @@ def min_(x):
 
 if __name__ == '__main__':
     import numba
-    numba.testmod()
+    numba.testing.testmod()
