@@ -1,5 +1,8 @@
+# -*- coding: utf-8 -*-
+from __future__ import print_function, division, absolute_import
+
 from numba import *
-from numba.tests import test_support
+from numba.testing import test_support
 
 import numpy
 
