@@ -14,6 +14,6 @@ def error():
 
 if __name__ == "__main__":
     import numba
-    from numba.tests.test_support import rewrite_doc
+    from numba.testing.test_support import rewrite_doc
     __doc__ = rewrite_doc(__doc__)
-    numba.testmod()
+    numba.testing.testmod()
