@@ -1,8 +1,6 @@
 import os
 from ctypes import *
-from numba import PY3
-from numba.pycc import find_shared_ending
-from numba.pycc import pycc
+from numba.pycc import find_shared_ending, main
 
 base_path = os.path.dirname(os.path.abspath(__file__))
 
@@ -12,7 +10,7 @@ def test_pycc():
     if os.path.exists(cdll_modulename):
         os.unlink(cdll_modulename)
 
-    pycc.main(args=[modulename + '.py'])
+    main(args=[modulename + '.py'])
     lib = CDLL(cdll_modulename)
 
     try:
@@ -36,7 +34,7 @@ def test_pycc():
 
     out_modulename = (os.path.join(base_path, 'compiled_with_pycc')
                       + find_shared_ending())
-    pycc.main(args=['--python', '-o', out_modulename, modulename + '.py'])
+    main(args=['--python', '-o', out_modulename, modulename + '.py'])
     try:
         import numba.tests.compiled_with_pycc as lib
         try:
@@ -54,7 +52,4 @@ def test_pycc():
             os.unlink(out_modulename)
 
 if __name__ == "__main__":
-    if PY3:
-        print('pycc is not yet supported in Python 3')
-    else:
-        test_pycc()
+    test_pycc()
