@@ -1,7 +1,8 @@
 import numpy as np
 import numba
 from numba import *
-from numba.tests.test_support import autojit_py3doc
+from numba.testing.test_support import autojit_py3doc
+
 @jit
 class Foo(object):
     def __init__(self, arg):
@@ -14,7 +15,7 @@ def test_typeof_pure(arg):
     >>> test_typeof_pure(10.0)
     double
     >>> print(test_typeof_pure(Foo(10)))
-    <Extension Foo({'arg': double})>
+    <JitExtension Foo({'arg': double})>
     """
     return numba.typeof(arg)
 
@@ -46,8 +47,8 @@ def test_typeof_numba3(arg):
     >>> print(test_typeof_numba3(10))
     int
     >>> print(test_typeof_numba3(Foo(10)))
-    <Extension Foo({'arg': double})>
+    <JitExtension Foo({'arg': double})>
     """
     return numba.typeof(arg)
 
-numba.testmod()
+numba.testing.testmod()
